Sources for demo
=================

galleryfield.models.BuiltInGalleryImage
----------------------------------------

.. autoclass:: galleryfield.models.BuiltInGalleryImage
   :members: creator, image
   :undoc-members:
   :show-inheritance:


demo.models.DemoGallery
------------------------
.. autoclass:: demo.models.DemoGallery
   :members: images, owner
   :undoc-members:
   :show-inheritance:

demo.views
------------------
.. automodule:: demo.views
   :members:
   :undoc-members:
   :show-inheritance:
